==> tuia-payment-center-api-0.0.44-yzhao12-20241219.071133-3-sources.jar: cn/tuia/payment/api/enums/PaymentChannelEnum.java <==
package cn.tuia.payment.api.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author lizhiheng
 */

@Getter
@AllArgsConstructor
public enum PaymentChannelEnum {
    LIANDONG(1, "联动"),
    WECHAT_MINI(2, "自研微信小程序"),
    FU_BEI(3, "付呗"),
    UNION_PAY(4, "银联"),
    CHENGSHI(5, "橙释"),
    SAND(6, "杉德"),
    ALI_PAY(7, "推啊支付宝"),
    LIANDONG_V2(8, "联动新"),
    SHOP(9, "店铺"),
    SHANGMENG(11, "商盟"),
    GUOGUANG(12, "国广"),
    HUIFU(13, "汇付"),
    ;

    public static final List<PaymentChannelEnum> bankMerList = Arrays.asList(LIANDONG, UNION_PAY, CHENGSHI, ALI_PAY, LIANDONG_V2, SHOP, SHANGMENG, GUOGUANG, HUIFU);
    public static final List<Integer> bankMerCodeList = bankMerList.stream().map(PaymentChannelEnum::getCode).collect(Collectors.toList());

    public static String convert2Name(Integer code) {
        for (PaymentChannelEnum paymentChannelEnum : PaymentChannelEnum.values()) {
            if (paymentChannelEnum.getCode().equals(code)) {
                return paymentChannelEnum.getName();
            }
        }
        return "";
    }

    private final Integer code;
    private final String name;

    public static PaymentChannelEnum fromCode(Integer channel) {
        for (PaymentChannelEnum value : PaymentChannelEnum.values()) {
            if (value.getCode().equals(channel)) {
                return value;
            }
        }
        return null;
    }
}

==> tuia-payment-center-api-0.0.45-yzhao-20241219.085057-10-sources.jar: cn/tuia/payment/api/enums/PaymentChannelEnum.java <==
package cn.tuia.payment.api.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author lizhiheng
 */

@Getter
@AllArgsConstructor
public enum PaymentChannelEnum {
    LIANDONG(1, "联动"),
    WECHAT_MINI(2, "自研微信小程序"),
    FU_BEI(3, "付呗"),
    UNION_PAY(4, "银联"),
    CHENGSHI(5, "橙释"),
    SAND(6, "杉德"),
    ALI_PAY(7, "推啊支付宝"),
    LIANDONG_V2(8, "联动新"),
    SHOP(9, "店铺"),
    SHANGMENG(11, "商盟"),
    GUOGUANG(12, "国广"),
    HUIFU(13, "汇付"),
    KUNPENG(14, "鲲鹏"),
    ;

    public static final List<PaymentChannelEnum> bankMerList = Arrays.asList(LIANDONG, UNION_PAY, CHENGSHI, ALI_PAY, LIANDONG_V2, SHOP, SHANGMENG, GUOGUANG, HUIFU,KUNPENG);
    public static final List<Integer> bankMerCodeList = bankMerList.stream().map(PaymentChannelEnum::getCode).collect(Collectors.toList());

    public static String convert2Name(Integer code) {
        for (PaymentChannelEnum paymentChannelEnum : PaymentChannelEnum.values()) {
            if (paymentChannelEnum.getCode().equals(code)) {
                return paymentChannelEnum.getName();
            }
        }
        return "";
    }

    private final Integer code;
    private final String name;

    public static PaymentChannelEnum fromCode(Integer channel) {
        for (PaymentChannelEnum value : PaymentChannelEnum.values()) {
            if (value.getCode().equals(channel)) {
                return value;
            }
        }
        return null;
    }
}
